import { DxBook, DxBookPage, DxBookPageIconsProps, DxIcon, DxParagraph } from "@/components";
import React, { FC, PropsWithChildren } from "react";
import { EmailLink, HhLink, IconLink, LinkTargetBlank, SpbDotNetLink } from "@/components/links";

const FlexList: FC<PropsWithChildren> = ({ children }) => <div className="flex flex-col">{children}</div>;

const left: DxBookPageIconsProps["left"] = [
  <IconLink href={"https://keroosha.t.me"} className={"fa-brands fa-telegram"} />,
  <IconLink href={"https://github.com/Keroosha"} className={"fa-brands fa-github"} />,
  <IconLink href={"https://www.last.fm/user/ykpon777"} className={"fa-brands fa-lastfm-square"} />,
  <IconLink href={"https://steamcommunity.com/id/keroosha"} className={"fa-brands fa-steam"} />,
];

const right: DxBookPageIconsProps["right"] = [];

const SkillzLine: FC<PropsWithChildren & { className: string }> = ({ className, children }) => (
  <div className={"flex m-1"}>
    <DxIcon className={"w-14 " + className} />
    <span>{children}</span>
  </div>
);

const Block: FC<PropsWithChildren & { title: string }> = ({ children, title }) => (
  <div className={"mb-5"}>
    <DxParagraph>{title}</DxParagraph>
    <FlexList>{children}</FlexList>
  </div>
);

export default function Home() {
  return (
    <DxBook className={"min-h-screen"} iconsProps={{ left, right }}>
      <DxBookPage
        title={"Whoami: Keroosha"}
        subTitle={".NET Developer, Meme Lord, Gun Owner, Music Nerd, SysOps and Anime"}
      >
        <Block title={"Key Skills:"}>
          <SkillzLine className={"fa-solid fa-server"}>.NET (C#/F#)</SkillzLine>
          <SkillzLine className={"fa-solid fa-database"}>PostgreSQL</SkillzLine>
          <SkillzLine className={"fa-solid fa-diagram-project"}>GraphQL</SkillzLine>
          <SkillzLine className={"fa-solid fa-users"}>OAuth2 (Idserver4/KeyCloak)</SkillzLine>
          <SkillzLine className={"fa-brands fa-linux"}>GNU/Linux</SkillzLine>
          <SkillzLine className={"fa-brands fa-node-js"}>Node.JS</SkillzLine>
          <SkillzLine className={"fa-brands fa-docker"}>Docker</SkillzLine>
          <SkillzLine className={"fa-brands fa-react"}>React</SkillzLine>
        </Block>

        <Block title="Talks:">
          <SpbDotNetLink />
        </Block>

        <Block title="Admin at:">
          <LinkTargetBlank href={"https://t.me/DotNetRuChat"}>Dotnet RU Chat</LinkTargetBlank>
          <LinkTargetBlank href={"https://t.me/netscapedidnothingwrong"}>Web 1.0</LinkTargetBlank>
          <LinkTargetBlank href={"https://t.me/pokupkabitka"}>Супер быстрая покупка битка</LinkTargetBlank>
        </Block>

        <Block title={"Hire Me:"}>
          <HhLink />
          <EmailLink />
        </Block>
      </DxBookPage>
    </DxBook>
  );
}
