import React, { FC, PropsWithChildren } from "react";

type RNode = PropsWithChildren["children"];
type DivProps = React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement>;
type IProps = React.DetailedHTMLProps<React.HTMLAttributes<HTMLElement>, HTMLElement>;
type ImgProps = React.DetailedHTMLProps<React.HTMLAttributes<HTMLImageElement>, HTMLImageElement>;
type PProps = React.DetailedHTMLProps<React.HTMLAttributes<HTMLParagraphElement>, HTMLParagraphElement>;

export type DxBookProps = DivProps & { iconsProps?: DxBookPageIconsProps };
export type DxBookPageProps = PropsWithChildren & { title: string; subTitle: string };
export type DxBookPageIconsProps = { left?: RNode; right?: RNode };

const DxBookPageDecoration = () => (
  <>
    <div className="ebook__side-gradient ebook__side-gradient_top"></div>
    <div className="ebook__side-gradient ebook__side-gradient_left"></div>
    <div className="ebook__side-gradient ebook__side-gradient_right"></div>
    <div className="ebook__side-gradient ebook__side-gradient_bottom"></div>
    <div className="ebook__corner-gradient ebook__corner-gradient_top-left"></div>
    <div className="ebook__corner-gradient ebook__corner-gradient_top-right"></div>
    <div className="ebook__corner-gradient ebook__corner-gradient_bottom-left"></div>
    <div className="ebook__corner-gradient ebook__corner-gradient_bottom-right"></div>
    <div className="ebook__dots-background"></div>
    <div className="ebook__vertical-borders"></div>
  </>
);

const DxBookPageIcons: FC<DxBookPageIconsProps> = ({ left, right }) => (
  <>
    <div className="ebook__icons">
      <div>{left}</div>
      <div>{right}</div>
    </div>
  </>
);

const DxNavigationStub: FC<PropsWithChildren> = () => (
  <nav className="navigation">
    <ul className="navigation__list">
      <li className="navigation__item">
        <a className="navigation__link" href="#">
          ●
        </a>
      </li>
      <li className="navigation__item">
        <a className="navigation__link" href="#">
          ○
        </a>
      </li>
      <li className="navigation__item">
        <a className="navigation__link" href="#">
          ○
        </a>
      </li>
    </ul>
  </nav>
);

export const DxBookPage: FC<DxBookPageProps> = ({ children, subTitle, title }) => (
  <section className={"ebook__content"}>
    <article className={"article"}>
      <header>
        <h1 className="article__title">{title}</h1>
        <p className="article__subtitle">{subTitle}</p>
      </header>
      {children}
    </article>
  </section>
);

export const DxParagraph: FC<PProps> = ({ children, ...rest }) => (
  <p {...rest} className={`article__text ${rest.className}`}>
    {children}
  </p>
);

export const DxIcon: FC<IProps> = ({ children, ...rest }) => (
  <i {...rest} className={`ebook__icon ebook__icon_book ${rest.className}`} aria-hidden="true">
    {children}
  </i>
);

export const DxImage: FC<ImgProps> = ({ ...props }) => (
  <img {...props} className={`article__image ${props.className}`} />
);

export const DxBook: FC<DxBookProps> = ({ children, iconsProps, ...rest }) => {
  return (
    <div {...rest} className={`page ${rest.className}`}>
      <section className={"ebook"}>
        <DxBookPageDecoration />
        <DxBookPageIcons {...(iconsProps ?? {})} />
        {/*<div className="ebook__flare" />*/}
        {children}
      </section>
      <div className={"mt-10"}>
        <a href={"https://github.com/cat-street/deus-ex-ebook/"}>Theme by cat-street</a>
      </div>
    </div>
  );
};
